@@ -1,11 +1,14 @@
 package Outthentic;
 
-our $VERSION = '0.0.7';
+our $VERSION = '0.0.8';
+
 
 1;
 
 package main;
 
+use Carp;
+
 use strict;
 use Test::More;
 use Data::Dumper;
@@ -71,7 +74,7 @@ sub run_story_file {
 
 sub header {
 
-    my $project = get_prop('project_root_dir');
+    my $project = project_root_dir();
     my $story = get_prop('story');
     my $story_type = get_prop('story_type');
     my $story_file = get_prop('story_file');
@@ -92,11 +95,23 @@ sub generate_asserts {
 
     header() if debug_mod12();
 
-    dsl->{debug_mod} = get_prop('debug');
+    dsl()->{debug_mod} = get_prop('debug');
 
     dsl()->{match_l} = get_prop('match_l');
+
     dsl()->{output} = run_story_file();
-    dsl()->generate_asserts($story_check_file);
+
+    eval { dsl()->validate($story_check_file) };
+
+    my $err = $@;
+
+    for my $r ( @{dsl()->results}){
+        ok($r->{status}, $r->{message}) if $r->{type} eq 'check_expression';
+        diag($r->{message}) if $r->{type} eq 'debug';
+
+    }
+
+    confess "parser error: $err" if $err;
 
 }
 
@@ -274,13 +289,13 @@ Let's create two stories for our calc project. One story to represent addition o
     print $calc->mult(3,4), "\n";
 
 
-=head2 Story checks
+=head2 Story check files
 
-Story checks are files that contain lines for validation of stdout from story scripts.
+Story check files (or short form story checks)  are files that contain lines for validation of stdout from story scripts.
 
-Story check file should be placed at the same directory as story file and named `story.check'.
+Story checks should be placed at the same directory as story file and named `story.check'.
 
-Following are story checks for a multiplication and addition stories:
+Following are story check for a multiplication and addition stories:
 
     # addition/story.check
     4
@@ -353,7 +368,7 @@ ODO makes validation of given stdout against given story check file
 
 =item *
 
-validation results in a I<sequence> of Test::More ok() asserts
+validation results are turned into a I<sequence> of Test::More ok() asserts
 
 
 =back
@@ -445,21 +460,22 @@ plain strings checks
 
 =back
 
-Often all you need is to ensure that http response has some strings in:
+Often all you need is to ensure that stdout has some strings in:
 
-    # http response
-    200 OK
+    # stdout
     HELLO
     HELLO WORLD
+    123456
     
     
     # check list
-    200 OK
     HELLO
+    123
     
-    # swat output
-    OK - output matches '200 OK'
+    # validation output
     OK - output matches 'HELLO'
+    OK - output matches 'HELLO WORLD'
+    OK - output matches '123'
 
 =over
 
@@ -472,19 +488,16 @@ regular expressions
 
 You may use regular expressions as well:
 
-    # http response
-    My birth day is: 1977-04-16
-    
-    
     # check list
-    regexp: \d\d\d\d-\d\d-\d\d
+    regexp: L+
+    regexp: \d
     
     
-    # swat output
-    OK - output matches /\d\d\d\d-\d\d-\d\d/
+    # validation output
+    OK - output matches /L+/
+    OK - output matches /\d/
 
-Follow L<https://github.com/melezhik/outthentic-dsl#comments-blank-lines-and-text-blocks|https://github.com/melezhik/outthentic-dsl#comments-blank-lines-and-text-blocks>
-to know more.
+Follow L<https://github.com/melezhik/outthentic-dsl#check-expressions|https://github.com/melezhik/outthentic-dsl#check-expressions> to know more.
 
 =over
 
@@ -514,8 +527,7 @@ Yes you may generate new check list on run time:
     hello
     again
 
-Follow L<https://github.com/melezhik/outthentic-dsl#generators|https://github.com/melezhik/outthentic-dsl#generators>
-to know more.
+Follow L<https://github.com/melezhik/outthentic-dsl#generators|https://github.com/melezhik/outthentic-dsl#generators> to know more.
 
 =over
 
@@ -530,10 +542,9 @@ What about inline arbitrary perl code? Well, it's easy!
 
     # check list
     regexp: number: (\d+)
-    code: cmp_ok( capture()->[0], '>=', 0, 'got none zero number');
+    validator: [ ( capture()->[0] '>=' 0 ), 'got none zero number') ];
 
-Follow L<https://github.com/melezhik/outthentic-dsl#perl-expressions|https://github.com/melezhik/outthentic-dsl#perl-expressions>
-to know more.
+Follow L<https://github.com/melezhik/outthentic-dsl#perl-expressions|https://github.com/melezhik/outthentic-dsl#validators> to know more.
 
 =over
 
@@ -544,9 +555,9 @@ text blocks
 
 =back
 
-Need to valiade that some lines goes in response successively ?
+Need to valiade that some lines goes successively?
 
-        # http response
+        # stdout
     
         this string followed by
         that string followed by
@@ -819,8 +830,29 @@ C<--root>  - root directory of outthentic project, if not set story runner start
 
 =item *
 
-C<--debug> - set to `1,2,3' if you want to see debug information in output, default value is `0'.
-Increasing debug value means more low level information appeared in console.
+C<--debug> - enable outthentic debugging
+
+=over
+
+=item *
+
+Increasing debug value results in more low level information appeared at output
+
+
+
+=item *
+
+Default value is 0, which means no debugging 
+
+
+
+=item *
+
+Possible values: 0,1,2,3
+
+
+
+=back
 
 
 
@@ -898,7 +930,7 @@ L<Outthentic::DSL|https://github.com/melezhik/outthentic-dsl>
 
 =item *
 
-L<swat|https://github.com/melezhik/swat>
+L<swat|https://github.com/melezhik/swat> 
 
 
 =back
